@@ -7,6 +7,7 @@ from .common import debug_print, walk
 from . import base
 from . import uv
 from . import qt
+from . import qta
 
 try:
     import pyuv
@@ -24,9 +25,16 @@ except ImportError:
         except ImportError:
             raise Exception("eventloop needs one of: pyuv or PySide2 or PyQt5 packages to work, none found")
 
+try:
+    import qasync
+    debug_print("using qasync")
+except ImportError:
+    pass
+
 has_pyuv = 'pyuv' in globals()
 has_PySide2 = 'PySide2' in globals()
 has_PyQt5 = 'PyQt5' in globals()
+has_qasync = 'qasync' in globals()
 
 """ template
 if has_pyuv:
@@ -39,7 +47,10 @@ def EventLoop(app = None):
     if has_pyuv:
         return uv.EventLoop()
     elif has_PySide2 or has_PyQt5:
-        return qt.EventLoop(app)
+        if has_qasync:
+            return qta.EventLoop(app)
+        else:    
+            return qt.EventLoop(app)
 
 def FileSystemWatch():
     if has_pyuv:
@@ -100,7 +111,7 @@ class Schedule:
         timer.start(timeout, self.on_timeout)
         self._timer = timer
 
-def on_file_changed(path, include=None, exclude=None, timeout=1, loop=None):
+def on_file_changed(path, include=None, exclude=None, timeout=1, loop=None, recursive=True):
 
     def decorator(func):
 
@@ -116,11 +127,15 @@ def on_file_changed(path, include=None, exclude=None, timeout=1, loop=None):
         
         watch = FileSystemWatch()
         schedule = Schedule(executor)
-        watch.start(path, on_change, recursive=True, include=include, exclude=exclude)
+        watch.start(path, on_change, recursive=recursive, include=include, exclude=exclude)
 
         if loop is None:
             loop_.start()
-    
+        else:
+            loop._handles.append(watch)
+            loop._handles.append(schedule)
+            loop._handles.append(executor)
+
         return func
     
     return decorator
