@@ -3,6 +3,9 @@ from .common import debug_print
 
 class EventLoop:
 
+    def __init__(self):
+        self._handles = []
+
     def start(self):
         pass
 
@@ -38,6 +41,7 @@ class FileSystemWatch:
             exclude = []
         self._include = include
         self._exclude = exclude
+        self._recursive = recursive
     
     def stop(self):
         pass
