@@ -4,6 +4,7 @@ from .common import debug_print, path_matches, EVENT_RENAME, EVENT_CHANGE
 import signal
 import sys
 import os
+import glob
 
 try:
     import pyuv
@@ -59,25 +60,36 @@ class FileSystemWatch(base.FileSystemWatch):
             print("Warning: recursive not implemented for this platform")
             # TODO: workaround for recursive
         loop = pyuv.Loop.default_loop()
-        handle = pyuv.fs.FSEvent(loop)
-        UV_FS_EVENT_RECURSIVE = 4
-        handle.start(path, UV_FS_EVENT_RECURSIVE if recursive else 0, self.onChanged)
-        handle.ref = False
-        self._watch = handle
-        self._isdir = os.path.isdir(path)
 
+        if glob.has_magic(path):
+            paths = glob.glob(path)
+        else:
+            paths = [path]
+
+        handles = []
+
+        UV_FS_EVENT_RECURSIVE = 4
+        flags = UV_FS_EVENT_RECURSIVE if recursive else 0
+
+        for path in paths:
+            handle = pyuv.fs.FSEvent(loop)
+            handle.start(path, flags, self.onChanged)
+            handle.ref = False
+            handles.append(handle)
+
+        self._handles = handles
     def stop(self):
         pass
 
     def onChanged(self, handle, filename, events, error):
         events_ = []
 
-        if self._isdir:
-            path = os.path.join(self._path, filename)
+        if os.path.isdir(handle.path):
+            path = os.path.join(handle.path, filename)
             if not path_matches(path, self._include, self._exclude):
                 return
         else:
-            path = self._path
+            path = handle.path
 
         if events & pyuv.fs.UV_RENAME:
             events_.append(EVENT_RENAME)
